@@ -80,6 +80,7 @@ class DuckDB(Dialect):
     class Tokenizer(tokens.Tokenizer):
         KEYWORDS = {
             **tokens.Tokenizer.KEYWORDS,
+            "~": TokenType.RLIKE,
             ":=": TokenType.EQ,
             "ATTACH": TokenType.COMMAND,
             "BINARY": TokenType.VARBINARY,
@@ -212,5 +213,7 @@ class DuckDB(Dialect):
             "except": "EXCLUDE",
         }
 
+        LIMIT_FETCH = "LIMIT"
+
         def tablesample_sql(self, expression: exp.TableSample, seed_prefix: str = "SEED") -> str:
             return super().tablesample_sql(expression, seed_prefix="REPEATABLE")
