@@ -20,6 +20,11 @@ class Redshift(Postgres):
     class Parser(Postgres.Parser):
         FUNCTIONS = {
             **Postgres.Parser.FUNCTIONS,  # type: ignore
+            "DATEADD": lambda args: exp.DateAdd(
+                this=seq_get(args, 2),
+                expression=seq_get(args, 1),
+                unit=seq_get(args, 0),
+            ),
             "DATEDIFF": lambda args: exp.DateDiff(
                 this=seq_get(args, 2),
                 expression=seq_get(args, 1),
@@ -76,13 +81,16 @@ class Redshift(Postgres):
         TRANSFORMS = {
             **Postgres.Generator.TRANSFORMS,  # type: ignore
             **transforms.ELIMINATE_DISTINCT_ON,  # type: ignore
+            exp.DateAdd: lambda self, e: self.func(
+                "DATEADD", exp.var(e.text("unit") or "day"), e.expression, e.this
+            ),
             exp.DateDiff: lambda self, e: self.func(
-                "DATEDIFF", e.args.get("unit") or "day", e.expression, e.this
+                "DATEDIFF", exp.var(e.text("unit") or "day"), e.expression, e.this
             ),
             exp.DistKeyProperty: lambda self, e: f"DISTKEY({e.name})",
-            exp.SortKeyProperty: lambda self, e: f"{'COMPOUND ' if e.args['compound'] else ''}SORTKEY({self.format_args(*e.this)})",
             exp.DistStyleProperty: lambda self, e: self.naked_property(e),
             exp.Matches: rename_func("DECODE"),
+            exp.SortKeyProperty: lambda self, e: f"{'COMPOUND ' if e.args['compound'] else ''}SORTKEY({self.format_args(*e.this)})",
         }
 
         # Redshift uses the POW | POWER (expr1, expr2) syntax instead of expr1 ^ expr2 (postgres)
