@@ -721,7 +721,8 @@ class Generator:
         temporary = " TEMPORARY" if expression.args.get("temporary") else ""
         materialized = " MATERIALIZED" if expression.args.get("materialized") else ""
         cascade = " CASCADE" if expression.args.get("cascade") else ""
-        return f"DROP{temporary}{materialized} {kind}{exists_sql}{this}{cascade}"
+        constraints = " CONSTRAINTS" if expression.args.get("constraints") else ""
+        return f"DROP{temporary}{materialized} {kind}{exists_sql}{this}{cascade}{constraints}"
 
     def except_sql(self, expression: exp.Except) -> str:
         return self.prepend_ctes(
@@ -1865,12 +1866,18 @@ class Generator:
     def ilike_sql(self, expression: exp.ILike) -> str:
         return self.binary(expression, "ILIKE")
 
+    def ilikeany_sql(self, expression: exp.ILikeAny) -> str:
+        return self.binary(expression, "ILIKE ANY")
+
     def is_sql(self, expression: exp.Is) -> str:
         return self.binary(expression, "IS")
 
     def like_sql(self, expression: exp.Like) -> str:
         return self.binary(expression, "LIKE")
 
+    def likeany_sql(self, expression: exp.LikeAny) -> str:
+        return self.binary(expression, "LIKE ANY")
+
     def similarto_sql(self, expression: exp.SimilarTo) -> str:
         return self.binary(expression, "SIMILAR TO")
 
