@@ -165,13 +165,14 @@ def _expand_alias_refs(scope, resolver):
 
         return node
 
-    where = scope.expression.args.get("where")
-    if where:
-        where.transform(transform, copy=False)
+    for select in scope.expression.selects:
+        select.transform(transform, copy=False)
 
-    group = scope.expression.args.get("group")
-    if group:
-        group.transform(transform, copy=False)
+    for modifier in ("where", "group"):
+        part = scope.expression.args.get(modifier)
+
+        if part:
+            part.transform(transform, copy=False)
 
 
 def _expand_group_by(scope, resolver):
